<!DOCTYPE TS><TS>
<context>
    <name>001</name>
    <message>
        <source>Error loading icon</source>
        <translation>Fehler beim Laden der Icons</translation>
    </message>
</context>
<context>
    <name>002</name>
    <message>
        <source>Error loading license</source>
        <translation>Fehler beim Laden des Lizenstextes</translation>
    </message>
</context>
<context>
    <name>003</name>
    <message>
        <source>This programme ist distributed under the terms of GPL v2.

File not found.</source>
        <translation>Dieses Programm wird unter den Bedingungen der GPL v2 veröffentlicht.

Datei nicht gefunden</translation>
    </message>
</context>
<context>
    <name>004</name>
    <message>
        <source>This programme ist distributed under the terms of GPL v2.

</source>
        <translation>Dieses Programm wird unter den Bedingungen der GPL v2 veröffentlicht.

</translation>
    </message>
</context>
<context>
    <name>005</name>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
<context>
    <name>006</name>
    <message>
        <source>Authors</source>
        <translation>Autoren</translation>
    </message>
</context>
<context>
    <name>007</name>
    <message>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
</context>
<context>
    <name>008</name>
    <message>
        <source>Calculator</source>
        <translation>Rechner</translation>
    </message>
</context>
<context>
    <name>009</name>
    <message>
        <source>Another Calculator</source>
        <translation>Noch ein Rechner</translation>
    </message>
</context>
<context>
    <name>010</name>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
</context>
<context>
    <name>011</name>
    <message>
        <source>Tables</source>
        <translation>Tabellen</translation>
    </message>
</context>
<context>
    <name>012</name>
    <message>
        <source>Script Editor</source>
        <translation>Script Editor</translation>
    </message>
</context>
<context>
    <name>013</name>
    <message>
        <source>Script Console</source>
        <translation>Script Konsole</translation>
    </message>
</context>
<context>
    <name>014</name>
    <message>
        <source>Import/Export Script</source>
        <translation>Script importieren/exportieren</translation>
    </message>
</context>
<context>
    <name>015</name>
    <message>
        <source>Import Script File</source>
        <translation>Script-Datei importieren</translation>
    </message>
</context>
<context>
    <name>016</name>
    <message>
        <source>File name to import</source>
        <translation>Zu Importierende Datei</translation>
    </message>
</context>
<context>
    <name>017</name>
    <message>
        <source>File name to save</source>
        <translation>Dateinamen zum Speichern</translation>
    </message>
</context>
<context>
    <name>018</name>
    <message>
        <source>Export Script File</source>
        <translation>Script-Datei exportieren</translation>
    </message>
</context>
<context>
    <name>019</name>
    <message>
        <source>Script file to export</source>
        <translation>Zu Exportierende Datein</translation>
    </message>
</context>
<context>
    <name>020</name>
    <message>
        <source>Unable to read variables file: </source>
        <translation>Variablen konnten nicht gelesen werden: </translation>
    </message>
</context>
<context>
    <name>021</name>
    <message>
        <source>Unable to write variables file: </source>
        <translation>Variablen konnten nicht geschrieben werden: </translation>
    </message>
</context>
<context>
    <name>022</name>
    <message>
        <source>Degree (DEG)</source>
        <translation>Grad (DEG)</translation>
    </message>
</context>
<context>
    <name>023</name>
    <message>
        <source>Radian (RAD)</source>
        <translation>Bogenmaß (RAD)</translation>
    </message>
</context>
<context>
    <name>024</name>
    <message>
        <source>Grad (GRA)</source>
        <translation>Altgrad (GRA)</translation>
    </message>
</context>
<context>
    <name>025</name>
    <message>
        <source>Fixed number of digits</source>
        <translation>Feste Stellenzahl</translation>
    </message>
</context>
<context>
    <name>026</name>
    <message>
        <source>Variable number of digits</source>
        <translation>Variable Stellenzahl</translation>
    </message>
</context>
<context>
    <name>027</name>
    <message>
        <source>With symbol</source>
        <translation>Mit Vorsatz-Zeichen</translation>
    </message>
</context>
<context>
    <name>028</name>
    <message>
        <source>Number of digits</source>
        <translation>Stellenzahl</translation>
    </message>
</context>
<context>
    <name>029</name>
    <message>
        <source>Angle</source>
        <translation>Winkelfunktionen</translation>
    </message>
</context>
<context>
    <name>030</name>
    <message>
        <source>Output Format</source>
        <translation>Ausgabeformat</translation>
    </message>
</context>
<context>
    <name>031</name>
    <message>
        <source>Calculator Preferences</source>
        <translation>Rechner-Einstellungen</translation>
    </message>
</context>
<context>
    <name>032</name>
    <message>
        <source>Graphics Preferences</source>
        <translation>Grafik-Einstellungen</translation>
    </message>
</context>
<context>
    <name>033</name>
    <message>
        <source>Extcalc Help</source>
        <translation>Extcalc-Hilfe</translation>
    </message>
</context>
<context>
    <name>034</name>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>035</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
</context>
<context>
    <name>036</name>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Einstellungen</translation>
    </message>
</context>
<context>
    <name>037</name>
    <message>
        <source>&amp;Calculator</source>
        <translation>&amp;Rechner</translation>
    </message>
</context>
<context>
    <name>038</name>
    <message>
        <source>&amp;Graphic</source>
        <translation>&amp;Grafik</translation>
    </message>
</context>
<context>
    <name>039</name>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
</context>
<context>
    <name>040</name>
    <message>
        <source>Set Standard Coordinates</source>
        <translation>Zurücksetzen standard</translation>
    </message>
</context>
<context>
    <name>041</name>
    <message>
        <source>Set Trigonometric Coordinates</source>
        <translation>Zurücksetzen trigonometrisch</translation>
    </message>
</context>
<context>
    <name>042</name>
    <message>
        <source>Show Axes</source>
        <translation>Achsen</translation>
    </message>
</context>
<context>
    <name>043</name>
    <message>
        <source>Show Labels</source>
        <translation>Achsenbeschriftung</translation>
    </message>
</context>
<context>
    <name>044</name>
    <message>
        <source>Show Raster</source>
        <translation>Raster</translation>
    </message>
</context>
<context>
    <name>045</name>
    <message>
        <source>Constant Width-To-Height-Ratio</source>
        <translation>Festes Seitenverhältnis</translation>
    </message>
</context>
<context>
    <name>046</name>
    <message>
        <source>Coordinate System</source>
        <translation>Koordinatensystem</translation>
    </message>
</context>
<context>
    <name>047</name>
    <message>
        <source>Graph Type</source>
        <translation>Zeichenformat</translation>
    </message>
</context>
<context>
    <name>048</name>
    <message>
        <source>Binary (BIN)</source>
        <translation>Binär (BIN)</translation>
    </message>
</context>
<context>
    <name>049</name>
    <message>
        <source>Octal (OCT)</source>
        <translation>Oktal (OCT)</translation>
    </message>
</context>
<context>
    <name>050</name>
    <message>
        <source>Decimal (DEC)</source>
        <translation>Dezimal (DEC)</translation>
    </message>
</context>
<context>
    <name>051</name>
    <message>
        <source>Hexadecimal (HEX)</source>
        <translation>Hexadezimal (HEX)</translation>
    </message>
</context>
<context>
    <name>052</name>
    <message>
        <source>Scientific Mode</source>
        <translation>Wissenschaftlicher Modus</translation>
    </message>
</context>
<context>
    <name>053</name>
    <message>
        <source>Base Mode</source>
        <translation>Logikmodus</translation>
    </message>
</context>
<context>
    <name>054</name>
    <message>
        <source>Base</source>
        <translation>Zahlensystem</translation>
    </message>
</context>
<context>
    <name>055</name>
    <message>
        <source>Mode</source>
        <translation>Rechenmodus</translation>
    </message>
</context>
<context>
    <name>056</name>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>057</name>
    <message>
        <source>Polar</source>
        <translation>Polar</translation>
    </message>
</context>
<context>
    <name>058</name>
    <message>
        <source>3D-Graph</source>
        <translation>3D-Grafik</translation>
    </message>
</context>
<context>
    <name>059</name>
    <message>
        <source>Normal</source>
        <translation>Normale Funktionen</translation>
    </message>
</context>
<context>
    <name>060</name>
    <message>
        <source>Polar</source>
        <translation>Polarfunktionen</translation>
    </message>
</context>
<context>
    <name>061</name>
    <message>
        <source>Parameter</source>
        <translation>Parameterfunktionen</translation>
    </message>
</context>
<context>
    <name>062</name>
    <message>
        <source>Inequality</source>
        <translation>Ungleichungen</translation>
    </message>
</context>
<context>
    <name>063</name>
    <message>
        <source>3D</source>
        <translation>3D-Funktionen</translation>
    </message>
</context>
<context>
    <name>064</name>
    <message>
        <source>Standard Values</source>
        <translation>Standardwerte</translation>
    </message>
</context>
<context>
    <name>065</name>
    <message>
        <source>Function Type</source>
        <translation>Functiontyp</translation>
    </message>
</context>
<context>
    <name>066</name>
    <message>
        <source>Table Preferences</source>
        <translation>Tabelleneinstellungen</translation>
    </message>
</context>
<context>
    <name>067</name>
    <message>
        <source>Table</source>
        <translation>Tabellen</translation>
    </message>
</context>
<context>
    <name>068</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
</context>
<context>
    <name>069</name>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
</context>
<context>
    <name>070</name>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
</context>
<context>
    <name>071</name>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
</context>
<context>
    <name>072</name>
    <message>
        <source>Paste</source>
        <translation>Enfügen</translation>
    </message>
</context>
<context>
    <name>073</name>
    <message>
        <source>View Calculator</source>
        <translation>Rechner</translation>
    </message>
</context>
<context>
    <name>074</name>
    <message>
        <source>View Second Calculator</source>
        <translation>2. Rechner</translation>
    </message>
</context>
<context>
    <name>075</name>
    <message>
        <source>View Graph Window</source>
        <translation>Graphikfenster</translation>
    </message>
</context>
<context>
    <name>076</name>
    <message>
        <source>View Table Window</source>
        <translation>Tabellenfenster</translation>
    </message>
</context>
<context>
    <name>077</name>
    <message>
        <source>View Scripting Window</source>
        <translation>Scriptfenster</translation>
    </message>
</context>
<context>
    <name>078</name>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>079</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
</context>
<context>
    <name>080</name>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
</context>
<context>
    <name>081</name>
    <message>
        <source>Scripting Preferences</source>
        <translation>Script Einstellungen</translation>
    </message>
</context>
<context>
    <name>082</name>
    <message>
        <source>View Script Console</source>
        <translation>Script-Konsole anzeigen</translation>
    </message>
</context>
<context>
    <name>083</name>
    <message>
        <source>Export Script</source>
        <translation>Script exportieren</translation>
    </message>
</context>
<context>
    <name>084</name>
    <message>
        <source>Import Script</source>
        <translation>Script importieren</translation>
    </message>
</context>
<context>
    <name>085</name>
    <message>
        <source>Always clear Array Memory</source>
        <translation>Array-Speicher automatisch löschen</translation>
    </message>
</context>
<context>
    <name>086</name>
    <message>
        <source>Clear Array Memory now</source>
        <translation>Array-Speicher jetzt löschen</translation>
    </message>
</context>
<context>
    <name>087</name>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
</context>
<context>
    <name>088</name>
    <message>
        <source>Complex</source>
        <translation>Komplexe Rechnung</translation>
    </message>
</context>
<context>
    <name>089</name>
    <message>
        <source>Reset Input Values</source>
        <translation>Eingabewerte zurücksetzen</translation>
    </message>
</context>
<context>
    <name>090</name>
    <message>
        <source>Clear Graphics Window</source>
        <translation>Grafik-Fenster jetzt löschen</translation>
    </message>
</context>
<context>
    <name>091</name>
    <message>
        <source>Automatic Graph Clear</source>
        <translation>Grafik-Fenster automatisch löschen</translation>
    </message>
</context>
<context>
    <name>092</name>
    <message>
        <source>Show Points</source>
        <translation>Punkte anzeigen</translation>
    </message>
</context>
<context>
    <name>093</name>
    <message>
        <source>Show Lines</source>
        <translation>Linien anzeigen</translation>
    </message>
</context>
<context>
    <name>094</name>
    <message>
        <source>Matrix/Vector</source>
        <translation>Matrix/Vektor</translation>
    </message>
</context>
<context>
    <name>095</name>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
</context>
<context>
    <name>096</name>
    <message>
        <source>Welcome to Extcalc!

This seems to be the first time, you start this program.
For this reason, Extcalc must create directories to store scripts and data.
Say yes, if you want to change the script configuration!</source>
        <translation>Willkommen in Extcalc!

Beim ersten Start von Extcalc, müssen Verzeichnisse zum Speichern von Script-Code und Script-Daten angelegt werden.
Drücken Sie Ja, um die Standard-Konfiguration jetzt zu ändern!</translation>
    </message>
</context>
<context>
    <name>097</name>
    <message>
        <source>Welcome to the new version of Extcalc!

This seems to be the first time, you start the new version of Extcalc.
The new version ships some default script programs.
The script directories must exist to make them usable.
Say yes, if you want to change the script configuration!</source>
        <translation>Willkommen in der neuen Version von Extcalc.

Diese Version enthält einige Beispiel-Script-Dateien. Um diese nutzen zu können, müssen Verzeichnisse zum Speichern von Code und Daten angelegt werden.
Drücken Sie Ja, um die Standard-Konfiguration jetzt zu ändern!</translation>
    </message>
</context>
<context>
    <name>098</name>
    <message>
        <source>Default directories created.</source>
        <translation>Die Standard-Verzeichnisse wurden angelegt.</translation>
    </message>
</context>
<context>
    <name>099</name>
    <message>
        <source>Complex</source>
        <translation>Komplexe Funktionen</translation>
    </message>
</context>
<context>
    <name>100</name>
    <message>
        <source>Error writing configfile: </source>
        <translation>Die folgende Konfigurationsdatei konnte nicht geschrieben werden:

</translation>
    </message>
</context>
<context>
    <name>101</name>
    <message>
        <source>Error loading configfile: </source>
        <translation>Die folgende Konfigurationsdatei konnte nicht geladen werden:

</translation>
    </message>
</context>
<context>
    <name>102</name>
    <message>
        <source>File outside script code directory: </source>
        <translation>Datei is außerhalb des Quellcode-Verzeichnisses: </translation>
    </message>
</context>
<context>
    <name>103</name>
    <message>
        <source>Really overwrite this file?

</source>
        <translation>Soll folgende Datei überschrieben werden?

</translation>
    </message>
</context>
<context>
    <name>104</name>
    <message>
        <source>Choose a script file to export</source>
        <translation>Script zum Exportieren auswählen</translation>
    </message>
</context>
<context>
    <name>105</name>
    <message>
        <source>Choose a file to import</source>
        <translation>Zu Importierendes Script auswählen</translation>
    </message>
</context>
<context>
    <name>106</name>
    <message>
        <source>open file dialog</source>
        <translation>open file dialog</translation>
    </message>
</context>
<context>
    <name>107</name>
    <message>
        <source>save file dialog</source>
        <translation>save file dialog</translation>
    </message>
</context>
<context>
    <name>108</name>
    <message>
        <source>Choose a filename to save under</source>
        <translation>Dateinamen zum Speichern auswählen</translation>
    </message>
</context>
<context>
    <name>109</name>
    <message>
        <source>Authors:
Rainer Strobel
Programming and development
Eugene Clement
Translation</source>
        <translation>Autoren:
Rainer Strobel
Programmierung und Entwicklung
Eugene Clement
Französische Übersetzung</translation>
    </message>
</context>
<context>
    <name>110</name>
    <message>
        <source>Change View</source>
        <translation>Ansicht ändern</translation>
    </message>
</context>
<context>
    <name>111</name>
    <message>
        <source>Scientific/Base Mode</source>
        <translation>wissenschaftlicher Modus/Logikmodus</translation>
    </message>
</context>
<context>
    <name>112</name>
    <message>
        <source>Set Base</source>
        <translation>Zahlensystem setzen</translation>
    </message>
</context>
<context>
    <name>113</name>
    <message>
        <source>Set Angle</source>
        <translation>Winkelformat setzen</translation>
    </message>
</context>
<context>
    <name>114</name>
    <message>
        <source>Function Catalog</source>
        <translation>Funktionsliste</translation>
    </message>
</context>
<context>
    <name>115</name>
    <message>
        <source>&amp;Undo<byte value="x9"/>Ctrl+Z</source>
        <translation>&amp;Rückgängig\tStrg+Z</translation>
    </message>
</context>
<context>
    <name>116</name>
    <message>
        <source>&amp;Redo<byte value="x9"/>Ctrl+Y</source>
        <translation>Wieder&amp;herstellen\tStrg+Y</translation>
    </message>
</context>
<context>
    <name>117</name>
    <message>
        <source>Cu&amp;t<byte value="x9"/>Ctrl+X</source>
        <translation>&amp;Ausschneiden\tStrg+X</translation>
    </message>
</context>
<context>
    <name>118</name>
    <message>
        <source>&amp;Copy<byte value="x9"/>Ctrl+C</source>
        <translation>&amp;Kopieren\tStrg+C</translation>
    </message>
</context>
<context>
    <name>119</name>
    <message>
        <source>&amp;Paste<byte value="x9"/>Ctrl+V</source>
        <translation>Ein&amp;fügen\tStrg+V</translation>
    </message>
</context>
<context>
    <name>120</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>121</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>122</name>
    <message>
        <source>Angle</source>
        <translation>Winkelfunktion</translation>
    </message>
</context>
<context>
    <name>123</name>
    <message>
        <source>Output Type</source>
        <translation>Ausgabeformat</translation>
    </message>
</context>
<context>
    <name>124</name>
    <message>
        <source>Output Digits</source>
        <translation>Stellenzahl</translation>
    </message>
</context>
<context>
    <name>125</name>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
</context>
<context>
    <name>126</name>
    <message>
        <source>Base</source>
        <translation>Zahlensystem</translation>
    </message>
</context>
<context>
    <name>127</name>
    <message>
        <source>Fixed Number of Digits</source>
        <translation>Feste Stellenzahl</translation>
    </message>
</context>
<context>
    <name>128</name>
    <message>
        <source>Variable Number of Digits</source>
        <translation>Variable Stellenzahl</translation>
    </message>
</context>
<context>
    <name>129</name>
    <message>
        <source>With Symbols</source>
        <translation>Mit Vorsatz-Zeichen</translation>
    </message>
</context>
<context>
    <name>130</name>
    <message>
        <source>Scientific</source>
        <translation>Wissenschaftlich</translation>
    </message>
</context>
<context>
    <name>131</name>
    <message>
        <source>Base</source>
        <translation>Logik</translation>
    </message>
</context>
<context>
    <name>132</name>
    <message>
        <source>Complex</source>
        <translation>Komplexe Zahlen</translation>
    </message>
</context>
<context>
    <name>133</name>
    <message>
        <source>Extcalc:
Graphic scientific calculator

</source>
        <translation>Extcalc:
Wissenschaftlicher grafischer Taschenrechner

</translation>
    </message>
</context>
<context>
    <name>134</name>
    <message>
        <source>Beta version
This program is still in development
(it may still have a few errors)  

</source>
        <translation>Entwicklungsversion:
 Teile des Programms können funktionslos oder beschädigt sein  

</translation>
    </message>
</context>
<context>
    <name>135</name>
    <message>
        <source>Print</source>
        <translation>Zeichnen</translation>
    </message>
</context>
<context>
    <name>136</name>
    <message>
        <source>Analyse</source>
        <translation>Auswerten</translation>
    </message>
</context>
<context>
    <name>137</name>
    <message>
        <source>Calculate Y-value</source>
        <translation>Y-Wert berechnen</translation>
    </message>
</context>
<context>
    <name>138</name>
    <message>
        <source>Calculate Roots</source>
        <translation>Nullstellen berechnen</translation>
    </message>
</context>
<context>
    <name>139</name>
    <message>
        <source>Newton&apos;s Method</source>
        <translation>Newton-Verfahren</translation>
    </message>
</context>
<context>
    <name>140</name>
    <message>
        <source>Calculate X-values</source>
        <translation>X-Werte berechnen</translation>
    </message>
</context>
<context>
    <name>141</name>
    <message>
        <source>Points of intersection</source>
        <translation>Schnittpunkte berechnen</translation>
    </message>
</context>
<context>
    <name>142</name>
    <message>
        <source>Maximum- and minimum values</source>
        <translation>Extremwerte berechnen</translation>
    </message>
</context>
<context>
    <name>143</name>
    <message>
        <source>calculate Integral</source>
        <translation>Integral berechnen</translation>
    </message>
</context>
<context>
    <name>144</name>
    <message>
        <source>calculate Differential</source>
        <translation>Differential berechnen</translation>
    </message>
</context>
<context>
    <name>145</name>
    <message>
        <source>Function</source>
        <translation>Funktion</translation>
    </message>
</context>
<context>
    <name>146</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
</context>
<context>
    <name>147</name>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
</context>
<context>
    <name>148</name>
    <message>
        <source>normal y(x)=x</source>
        <translation>Normal y(x)=x</translation>
    </message>
</context>
<context>
    <name>149</name>
    <message>
        <source>polar r(x)=x</source>
        <translation>Polar r(x)=x</translation>
    </message>
</context>
<context>
    <name>150</name>
    <message>
        <source>parameter x=T; y=T</source>
        <translation>Parameter x=T; y=T</translation>
    </message>
</context>
<context>
    <name>151</name>
    <message>
        <source>3d y(xz)=xz</source>
        <translation>3D y(x,z)=xz</translation>
    </message>
</context>
<context>
    <name>152</name>
    <message>
        <source>inequality y(x)&gt;x</source>
        <translation>Ungleichung y(x)&gt;x</translation>
    </message>
</context>
<context>
    <name>153</name>
    <message>
        <source>inequality y(x)&lt;x</source>
        <translation>Ungleichung y(x)&lt;x</translation>
    </message>
</context>
<context>
    <name>154</name>
    <message>
        <source>inequality y(x)&gt;=x</source>
        <translation>Ungleichung y(x)&gt;=x</translation>
    </message>
</context>
<context>
    <name>155</name>
    <message>
        <source>inequality y(x)&lt;=x</source>
        <translation>Ungleichung y(x)&lt;=x</translation>
    </message>
</context>
<context>
    <name>156</name>
    <message>
        <source>Type</source>
        <translation>Funktionstyp</translation>
    </message>
</context>
<context>
    <name>157</name>
    <message>
        <source>calculate Z-values</source>
        <translation>Z-Wert berechnen</translation>
    </message>
</context>
<context>
    <name>158</name>
    <message>
        <source>Save and modify</source>
        <translation>Speichern und zeichnen</translation>
    </message>
</context>
<context>
    <name>159</name>
    <message>
        <source>Edit</source>
        <translation>Eingabe</translation>
    </message>
</context>
<context>
    <name>160</name>
    <message>
        <source>Anlayse</source>
        <translation>Auswerten</translation>
    </message>
</context>
<context>
    <name>161</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
</context>
<context>
    <name>162</name>
    <message>
        <source>Nyquist Plots</source>
        <translation>Ortskurve</translation>
    </message>
</context>
<context>
    <name>163</name>
    <message>
        <source>black</source>
        <translation>schwarz</translation>
    </message>
</context>
<context>
    <name>164</name>
    <message>
        <source>grey</source>
        <translation>grau</translation>
    </message>
</context>
<context>
    <name>165</name>
    <message>
        <source>brown</source>
        <translation>braun</translation>
    </message>
</context>
<context>
    <name>166</name>
    <message>
        <source>green</source>
        <translation>grün</translation>
    </message>
</context>
<context>
    <name>167</name>
    <message>
        <source>blue</source>
        <translation>blau</translation>
    </message>
</context>
<context>
    <name>168</name>
    <message>
        <source>magenta</source>
        <translation>violet</translation>
    </message>
</context>
<context>
    <name>169</name>
    <message>
        <source>orange</source>
        <translation>orange</translation>
    </message>
</context>
<context>
    <name>170</name>
    <message>
        <source>red</source>
        <translation>rot</translation>
    </message>
</context>
<context>
    <name>171</name>
    <message>
        <source>yellow</source>
        <translation>gelb</translation>
    </message>
</context>
<context>
    <name>172</name>
    <message>
        <source>cyan</source>
        <translation>türkis</translation>
    </message>
</context>
<context>
    <name>173</name>
    <message>
        <source>colored</source>
        <translation>bunt</translation>
    </message>
</context>
<context>
    <name>174</name>
    <message>
        <source>Analyse</source>
        <translation>Auswerten</translation>
    </message>
</context>
<context>
    <name>175</name>
    <message>
        <source>Edit Mode</source>
        <translation>Eingabe</translation>
    </message>
</context>
<context>
    <name>176</name>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
<context>
    <name>177</name>
    <message>
        <source>Extcalc - Draw Text</source>
        <translation>Extcalc - Text zeichnen</translation>
    </message>
</context>
<context>
    <name>178</name>
    <message>
        <source>Enter text to draw:</source>
        <translation>Text zum Zeichnen eingeben:</translation>
    </message>
</context>
<context>
    <name>179</name>
    <message>
        <source>Extcalc - Preferences</source>
        <translation>Extcalc - Einstellungen</translation>
    </message>
</context>
<context>
    <name>180</name>
    <message>
        <source>Cartesian Coordinate System</source>
        <translation>Kartesisches Koordinatensystem</translation>
    </message>
</context>
<context>
    <name>181</name>
    <message>
        <source>Raster</source>
        <translation>Raster</translation>
    </message>
</context>
<context>
    <name>182</name>
    <message>
        <source>Axes</source>
        <translation>Koordinatenachsen</translation>
    </message>
</context>
<context>
    <name>183</name>
    <message>
        <source>Labels</source>
        <translation>Achsenbeschriftung</translation>
    </message>
</context>
<context>
    <name>184</name>
    <message>
        <source>constant width-to-height ratio</source>
        <translation>Seitenverhältnis beibehalten</translation>
    </message>
</context>
<context>
    <name>185</name>
    <message>
        <source>X-Scale</source>
        <translation>X-Einteilung</translation>
    </message>
</context>
<context>
    <name>186</name>
    <message>
        <source>Y-Scale</source>
        <translation>Y-Einteilung</translation>
    </message>
</context>
<context>
    <name>187</name>
    <message>
        <source>Coordinate System Format:</source>
        <translation>Koordinatensystem Format</translation>
    </message>
</context>
<context>
    <name>188</name>
    <message>
        <source>Polar Coordinate System</source>
        <translation>Polares Koordinatemsystem</translation>
    </message>
</context>
<context>
    <name>189</name>
    <message>
        <source>max angle:</source>
        <translation>Max. Winkel:</translation>
    </message>
</context>
<context>
    <name>190</name>
    <message>
        <source>max radius:</source>
        <translation>Max Radius:</translation>
    </message>
</context>
<context>
    <name>191</name>
    <message>
        <source>angle scale:</source>
        <translation>Winkel Einteilung:</translation>
    </message>
</context>
<context>
    <name>192</name>
    <message>
        <source>radius scale:</source>
        <translation>Radius Einteilung:</translation>
    </message>
</context>
<context>
    <name>193</name>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>194</name>
    <message>
        <source>Polar</source>
        <translation>Polar</translation>
    </message>
</context>
<context>
    <name>195</name>
    <message>
        <source>3D-Graph</source>
        <translation>3D-Grafik</translation>
    </message>
</context>
<context>
    <name>196</name>
    <message>
        <source>Range of Parameter T:</source>
        <translation>Grenzen des Parameters T:</translation>
    </message>
</context>
<context>
    <name>197</name>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
</context>
<context>
    <name>198</name>
    <message>
        <source>End:</source>
        <translation>Ende:</translation>
    </message>
</context>
<context>
    <name>199</name>
    <message>
        <source>Z-Scale</source>
        <translation>Z-Einteilung</translation>
    </message>
</context>
<context>
    <name>200</name>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
</context>
<context>
    <name>201</name>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>202</name>
    <message>
        <source>Preferences for Parameter A:</source>
        <translation>Einstellungen für Parameter A:</translation>
    </message>
</context>
<context>
    <name>203</name>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
</context>
<context>
    <name>204</name>
    <message>
        <source>End:</source>
        <translation>Ende:</translation>
    </message>
</context>
<context>
    <name>205</name>
    <message>
        <source>Steps:</source>
        <translation>Schritte:</translation>
    </message>
</context>
<context>
    <name>206</name>
    <message>
        <source>Delay Time (*10ms):</source>
        <translation>Verzögerung (*10ms):</translation>
    </message>
</context>
<context>
    <name>207</name>
    <message>
        <source>Automatic Mode</source>
        <translation>Automatik Modus</translation>
    </message>
</context>
<context>
    <name>208</name>
    <message>
        <source>Count up only</source>
        <translation>Nur aufwärts zählen</translation>
    </message>
</context>
<context>
    <name>209</name>
    <message>
        <source>Count up and down</source>
        <translation>Auf und ab zählen</translation>
    </message>
</context>
<context>
    <name>210</name>
    <message>
        <source>Coordinate Systems</source>
        <translation>Koordinatensystem</translation>
    </message>
</context>
<context>
    <name>211</name>
    <message>
        <source>Precision/Performance</source>
        <translation>Rechenleistung/Genauigkeit</translation>
    </message>
</context>
<context>
    <name>212</name>
    <message>
        <source>Parameter Range</source>
        <translation>Paramteter T,A,Z</translation>
    </message>
</context>
<context>
    <name>213</name>
    <message>
        <source>Calculation steps for 2D-Graphs</source>
        <translation>Rechenschritte für 2D-Graphen</translation>
    </message>
</context>
<context>
    <name>214</name>
    <message>
        <source>Calculation steps for 3D-Graphs</source>
        <translation>Rechenschritte für 3D-Graphen</translation>
    </message>
</context>
<context>
    <name>215</name>
    <message>
        <source>Parameter graph steps</source>
        <translation>Rechenschritte für Parameterfunktionen</translation>
    </message>
</context>
<context>
    <name>216</name>
    <message>
        <source>Steps for Nyquist Plot</source>
        <translation>Rechenschritte für Ortskurven</translation>
    </message>
</context>
<context>
    <name>217</name>
    <message>
        <source>Graph Analysation Precision</source>
        <translation>Analyse-Genauigkeit</translation>
    </message>
</context>
<context>
    <name>218</name>
    <message>
        <source>Low</source>
        <translation>niedrig</translation>
    </message>
</context>
<context>
    <name>219</name>
    <message>
        <source>Standard</source>
        <translation>normal</translation>
    </message>
</context>
<context>
    <name>220</name>
    <message>
        <source>High</source>
        <translation>hoch</translation>
    </message>
</context>
<context>
    <name>221</name>
    <message>
        <source>Draw 3D-Graphs as Grid</source>
        <translation>3D-Graphen als Gitternetz anzeigen</translation>
    </message>
</context>
<context>
    <name>222</name>
    <message>
        <source>Parameter Z for Nyquist plots (2D only)</source>
        <translation>Parameter Z für 2D-Ortskurven</translation>
    </message>
</context>
<context>
    <name>223</name>
    <message>
        <source>Start value:</source>
        <translation>Startwert:</translation>
    </message>
</context>
<context>
    <name>224</name>
    <message>
        <source>End value:</source>
        <translation>Endwert:</translation>
    </message>
</context>
<context>
    <name>225</name>
    <message>
        <source>Use logarithmic scale (10^Z)</source>
        <translation>Logarithmische Schritte (10^Z)</translation>
    </message>
</context>
<context>
    <name>226</name>
    <message>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>227</name>
    <message>
        <source>Trigonometric</source>
        <translation>Winkelfunktionen</translation>
    </message>
</context>
<context>
    <name>228</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>229</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>230</name>
    <message>
        <source>Error

The minimal X-value must be lower than the maximal X-value</source>
        <translation>Fehler

Der minimale X-Wert muss kleiner sein als der maximale X-Wert!</translation>
    </message>
</context>
<context>
    <name>231</name>
    <message>
        <source>Error

The minimal Y-value must be lower than the maximal Y-value</source>
        <translation>Fehler

Der minimale Y-Wert muss kleiner sein als der maximale Y-Wert!</translation>
    </message>
</context>
<context>
    <name>232</name>
    <message>
        <source>Error

X-Scale must be positive</source>
        <translation>Fehler

Der X-Raster-Abstand muss positiv sein!</translation>
    </message>
</context>
<context>
    <name>233</name>
    <message>
        <source>Error

Y-Scale must be positive</source>
        <translation>Fehler

Der Y-Raster-Abstand muss positiv sein!</translation>
    </message>
</context>
<context>
    <name>234</name>
    <message>
        <source>Error

Please choose two different functions!</source>
        <translation>Fehler

Bitte wählen Sie zwei verschiedene Funktionen aus!</translation>
    </message>
</context>
<context>
    <name>235</name>
    <message>
        <source>Error

Too many results!</source>
        <translation>Fehler

Zu viele Ergebnisse!</translation>
    </message>
</context>
<context>
    <name>236</name>
    <message>
        <source>Max angle must be greater than zero</source>
        <translation>Maximaler Winkel muss größer Null sein</translation>
    </message>
</context>
<context>
    <name>237</name>
    <message>
        <source>Max Radius must be greater than zero</source>
        <translation>Maximaler Radius muss größer Null sein</translation>
    </message>
</context>
<context>
    <name>238</name>
    <message>
        <source>Angle scale must be greater than zero</source>
        <translation>Maximale Winkeleinteilung muss größer Null sein</translation>
    </message>
</context>
<context>
    <name>239</name>
    <message>
        <source>Radius scale must be greater than zero</source>
        <translation>Maximale Radiuseinteilung muss größer Null sein</translation>
    </message>
</context>
<context>
    <name>240</name>
    <message>
        <source>Parameter start value must be less than parameter end value</source>
        <translation>Parameterfunktions-Startwert muss kleiner sein als Endwert</translation>
    </message>
</context>
<context>
    <name>241</name>
    <message>
        <source>Error

Z-scale must be positive</source>
        <translation>Fehler

Der Z-Raster-Abstand muss positiv sein!</translation>
    </message>
</context>
<context>
    <name>242</name>
    <message>
        <source>Error

The minimal Z-value must be lower than the maximal Z-value</source>
        <translation>Fehler

Der minimale Z-Wert muss kleiner sein als der maximale Z-Wert!</translation>
    </message>
</context>
<context>
    <name>243</name>
    <message>
        <source>Steps must be greather than 0</source>
        <translation>Die Schrittzahl muss größer 0 sein!</translation>
    </message>
</context>
<context>
    <name>244</name>
    <message>
        <source>Dynamic parameter end must be greather than start!</source>
        <translation>Der Endwert für Parameter A muss größer als der Startwert sein!</translation>
    </message>
</context>
<context>
    <name>245</name>
    <message>
        <source>Delay time must be greather than 0</source>
        <translation>Die Verzögerungszeit muss größer 0 sein!</translation>
    </message>
</context>
<context>
    <name>246</name>
    <message>
        <source>Calculate</source>
        <translation>Berechnen</translation>
    </message>
</context>
<context>
    <name>247</name>
    <message>
        <source>Parameter A:</source>
        <translation>Parameter A:</translation>
    </message>
</context>
<context>
    <name>248</name>
    <message>
        <source>Width</source>
        <translation>Stärke</translation>
    </message>
</context>
<context>
    <name>249</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>250</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
</context>
<context>
    <name>251</name>
    <message>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
</context>
<context>
    <name>252</name>
    <message>
        <source>Clear</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>253</name>
    <message>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
</context>
<context>
    <name>254</name>
    <message>
        <source>Insert X-Value:</source>
        <translation>X-Wert eingeben:</translation>
    </message>
</context>
<context>
    <name>255</name>
    <message>
        <source>Y-Values:</source>
        <translation>Y-Werte:</translation>
    </message>
</context>
<context>
    <name>256</name>
    <message>
        <source>Choose Function:</source>
        <translation>Funktion auswählen</translation>
    </message>
</context>
<context>
    <name>257</name>
    <message>
        <source>Roots:</source>
        <translation>Nullstellen:</translation>
    </message>
</context>
<context>
    <name>258</name>
    <message>
        <source>Start Point:</source>
        <translation>Startwert:</translation>
    </message>
</context>
<context>
    <name>259</name>
    <message>
        <source>Steps:</source>
        <translation>Anzahl der Schritte:</translation>
    </message>
</context>
<context>
    <name>260</name>
    <message>
        <source>X-Values:</source>
        <translation>X-Werte:</translation>
    </message>
</context>
<context>
    <name>261</name>
    <message>
        <source>Y-Value:</source>
        <translation>Y-Wert:</translation>
    </message>
</context>
<context>
    <name>262</name>
    <message>
        <source>Points of Intersection:</source>
        <translation>Schnittpunkte:</translation>
    </message>
</context>
<context>
    <name>263</name>
    <message>
        <source>1. Function</source>
        <translation>1. Funktion</translation>
    </message>
</context>
<context>
    <name>264</name>
    <message>
        <source>2. Function</source>
        <translation>2.Funktion</translation>
    </message>
</context>
<context>
    <name>265</name>
    <message>
        <source>Start Point:</source>
        <translation>Startwert:</translation>
    </message>
</context>
<context>
    <name>266</name>
    <message>
        <source>End Point:</source>
        <translation>Endwert:</translation>
    </message>
</context>
<context>
    <name>267</name>
    <message>
        <source>X-Value:</source>
        <translation>X-Wert:</translation>
    </message>
</context>
<context>
    <name>268</name>
    <message>
        <source>Invalid start point</source>
        <translation>Startwert ungültig</translation>
    </message>
</context>
<context>
    <name>269</name>
    <message>
        <source>Invalid end point</source>
        <translation>Endwert ungültig</translation>
    </message>
</context>
<context>
    <name>270</name>
    <message>
        <source>Invalid X-Value</source>
        <translation>X-Wert ungültig</translation>
    </message>
</context>
<context>
    <name>271</name>
    <message>
        <source>Extreme Values</source>
        <translation>Extremverte</translation>
    </message>
</context>
<context>
    <name>272</name>
    <message>
        <source>Results</source>
        <translation>Ergebnisse</translation>
    </message>
</context>
<context>
    <name>273</name>
    <message>
        <source>X-value</source>
        <translation>X-Wert</translation>
    </message>
</context>
<context>
    <name>274</name>
    <message>
        <source>Y-value</source>
        <translation>Y-Wert</translation>
    </message>
</context>
<context>
    <name>275</name>
    <message>
        <source>Z-value</source>
        <translation>Z-Wert</translation>
    </message>
</context>
<context>
    <name>276</name>
    <message>
        <source>T-value</source>
        <translation>T-Wert</translation>
    </message>
</context>
<context>
    <name>277</name>
    <message>
        <source>z start:</source>
        <translation>z Start</translation>
    </message>
</context>
<context>
    <name>278</name>
    <message>
        <source>end:</source>
        <translation>Ende</translation>
    </message>
</context>
<context>
    <name>279</name>
    <message>
        <source>x start:</source>
        <translation>x Start</translation>
    </message>
</context>
<context>
    <name>280</name>
    <message>
        <source>end:</source>
        <translation>Ende</translation>
    </message>
</context>
<context>
    <name>281</name>
    <message>
        <source>Path:</source>
        <translation>Pfad</translation>
    </message>
</context>
<context>
    <name>282</name>
    <message>
        <source>Resolution:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>283</name>
    <message>
        <source>File format:</source>
        <translation>Dateiformat:</translation>
    </message>
</context>
<context>
    <name>284</name>
    <message>
        <source>Please insert a valid path to save screenshot</source>
        <translation>Bitte gültigen Dateinamen eingeben!</translation>
    </message>
</context>
<context>
    <name>285</name>
    <message>
        <source>Really overwrite file </source>
        <translation>Soll folgende Datei wirklich überschrieben werden: </translation>
    </message>
</context>
<context>
    <name>286</name>
    <message>
        <source> is no valid file.
 Can&apos;t overwrite it!</source>
        <translation> ist keine gültige Datei.
 Sie kann nicht überschrieben werden!</translation>
    </message>
</context>
<context>
    <name>287</name>
    <message>
        <source>Screenshot saved</source>
        <translation>Screenshot gespeichert.</translation>
    </message>
</context>
<context>
    <name>288</name>
    <message>
        <source>Error saving screenshot</source>
        <translation>Screenshot speichern fehlgeschlagen!</translation>
    </message>
</context>
<context>
    <name>289</name>
    <message>
        <source>Images (*.png *.xpm *.jpg *.bmp)</source>
        <translation>Bilder (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
</context>
<context>
    <name>290</name>
    <message>
        <source>Choose a filename to save under</source>
        <translation>Dateinamen zum speichern wählen</translation>
    </message>
</context>
<context>
    <name>291</name>
    <message>
        <source>Color Dialog</source>
        <translation>Farbdialog</translation>
    </message>
</context>
<context>
    <name>292</name>
    <message>
        <source>Insert real value</source>
        <translation>Realteil eingeben</translation>
    </message>
</context>
<context>
    <name>293</name>
    <message>
        <source>Imaginary values</source>
        <translation>Imaginäranteile</translation>
    </message>
</context>
<context>
    <name>294</name>
    <message>
        <source>Real values</source>
        <translation>Realanteile</translation>
    </message>
</context>
<context>
    <name>295</name>
    <message>
        <source>Imaginary value</source>
        <translation>Imaginärteil eingeben</translation>
    </message>
</context>
<context>
    <name>296</name>
    <message>
        <source>By Extension</source>
        <translation>Nach Endung</translation>
    </message>
</context>
<context>
    <name>297</name>
    <message>
        <source>Unknown file format!
Assuming png.</source>
        <translation>Unbekanntes Dateiformat!
Es wird png angenommen.</translation>
    </message>
</context>
<context>
    <name>298</name>
    <message>
        <source>Calculate</source>
        <translation>Berechnen</translation>
    </message>
</context>
<context>
    <name>299</name>
    <message>
        <source>normal</source>
        <translation>Normal</translation>
    </message>
</context>
<context>
    <name>300</name>
    <message>
        <source>polar</source>
        <translation>Polar</translation>
    </message>
</context>
<context>
    <name>301</name>
    <message>
        <source>parameter</source>
        <translation>Parameter</translation>
    </message>
</context>
<context>
    <name>302</name>
    <message>
        <source>inequality</source>
        <translation>Ungleichungen</translation>
    </message>
</context>
<context>
    <name>303</name>
    <message>
        <source>3D</source>
        <translation>3D</translation>
    </message>
</context>
<context>
    <name>304</name>
    <message>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
</context>
<context>
    <name>305</name>
    <message>
        <source>Complex</source>
        <translation>Komplex</translation>
    </message>
</context>
<context>
    <name>306</name>
    <message>
        <source>Extcalc - Table</source>
        <translation>Extcalc - Tabellen</translation>
    </message>
</context>
<context>
    <name>307</name>
    <message>
        <source>Enter column value </source>
        <translation>Wert eingeben für Spalte </translation>
    </message>
</context>
<context>
    <name>308</name>
    <message>
        <source>Enter row value </source>
        <translation>Wert eingeben für Zeile </translation>
    </message>
</context>
<context>
    <name>309</name>
    <message>
        <source>Change View</source>
        <translation>Ansicht ändern</translation>
    </message>
</context>
<context>
    <name>310</name>
    <message>
        <source>Choose Function Type</source>
        <translation>Funktionstyp auswählen</translation>
    </message>
</context>
<context>
    <name>311</name>
    <message>
        <source>Function Catalog</source>
        <translation>Funktionsliste</translation>
    </message>
</context>
<context>
    <name>312</name>
    <message>
        <source>Table Preferences</source>
        <translation>Tabellen Einstellungen</translation>
    </message>
</context>
<context>
    <name>313</name>
    <message>
        <source>Function Type:</source>
        <translation>Functionstyp:</translation>
    </message>
</context>
<context>
    <name>314</name>
    <message>
        <source>Parameter x, T start value</source>
        <translation>Parameter X, T Startwert</translation>
    </message>
</context>
<context>
    <name>315</name>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
</context>
<context>
    <name>316</name>
    <message>
        <source>End value</source>
        <translation>Endwert</translation>
    </message>
</context>
<context>
    <name>317</name>
    <message>
        <source>Parameter Z start value</source>
        <translation>Parameter Z Startwert</translation>
    </message>
</context>
<context>
    <name>318</name>
    <message>
        <source>End value</source>
        <translation>Endwert</translation>
    </message>
</context>
<context>
    <name>319</name>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
</context>
<context>
    <name>320</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>321</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>322</name>
    <message>
        <source>Table Preferences</source>
        <translation>Tabllen-Einstellungen</translation>
    </message>
</context>
<context>
    <name>323</name>
    <message>
        <source>Parameter X,T,complex Z</source>
        <translation>Parameter X,T,Z komplex</translation>
    </message>
</context>
<context>
    <name>324</name>
    <message>
        <source>Parameter Z (3D)</source>
        <translation>Parameter Z (3D)</translation>
    </message>
</context>
<context>
    <name>325</name>
    <message>
        <source>Value for dynamic parameter A:</source>
        <translation>Wert für dynamischen Parameter A:</translation>
    </message>
</context>
<context>
    <name>326</name>
    <message>
        <source>Start:</source>
        <translation>Start:</translation>
    </message>
</context>
<context>
    <name>327</name>
    <message>
        <source>Steps:</source>
        <translation>Schritte:</translation>
    </message>
</context>
<context>
    <name>328</name>
    <message>
        <source>End:</source>
        <translation>Ende:</translation>
    </message>
</context>
<context>
    <name>329</name>
    <message>
        <source>X-Start value invalid</source>
        <translation>X-Startwert ungültig!</translation>
    </message>
</context>
<context>
    <name>330</name>
    <message>
        <source>X-End value invalid</source>
        <translation>X-Endwert ungültig!</translation>
    </message>
</context>
<context>
    <name>331</name>
    <message>
        <source>Z-Start value invalid</source>
        <translation>Z-Startwert ungültig!</translation>
    </message>
</context>
<context>
    <name>332</name>
    <message>
        <source>Z-End value invalid</source>
        <translation>Z-Endwert ungültig!</translation>
    </message>
</context>
<context>
    <name>333</name>
    <message>
        <source>X-End value must be greather then X-Start value</source>
        <translation>X-Endwert muss größer als X-Startwert sein!</translation>
    </message>
</context>
<context>
    <name>334</name>
    <message>
        <source>Z-End value must be greather then Z-Start value</source>
        <translation>Z-Endwert muss größer als Z-Startwert sein!</translation>
    </message>
</context>
<context>
    <name>335</name>
    <message>
        <source>X-Steps must be greather than 0</source>
        <translation>X-Schrittzahl muss größer Null sein!</translation>
    </message>
</context>
<context>
    <name>336</name>
    <message>
        <source>Z-Steps must be greather than 0</source>
        <translation>Z-Schrittzahl muss größer Null sein!</translation>
    </message>
</context>
<context>
    <name>337</name>
    <message>
        <source>Kill</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>338</name>
    <message>
        <source>Script could not be stopped.
You may press the kill button again.</source>
        <translation>Das Programm konnte nicht abgebrochen werden.
Drücken Sie bitte noch einmal den Abbrechen-Knopf.</translation>
    </message>
</context>
<context>
    <name>339</name>
    <message>
        <source>
*** killed ***
</source>
        <translation>
*** abgebrochen ***
</translation>
    </message>
</context>
<context>
    <name>340</name>
    <message>
        <source>
*** finish ***
</source>
        <translation>
*** beendet ***
</translation>
    </message>
</context>
<context>
    <name>341</name>
    <message>
        <source>You are already running a script.
Kill it?</source>
        <translation>Es läuft bereits ein Programm.
Soll es beendet werden?</translation>
    </message>
</context>
<context>
    <name>342</name>
    <message>
        <source>
*** script ***
</source>
        <translation>
*** script ***
</translation>
    </message>
</context>
<context>
    <name>343</name>
    <message>
        <source>Run</source>
        <translation>Ausführen</translation>
    </message>
</context>
<context>
    <name>344</name>
    <message>
        <source>
Processing main file ...</source>
        <translation>
Lade Hauptdatei ...</translation>
    </message>
</context>
<context>
    <name>345</name>
    <message>
        <source>
Processing file </source>
        <translation>
Lade Datei </translation>
    </message>
</context>
<context>
    <name>346</name>
    <message>
        <source>
Script sucessfully loaded.
Now you can press run.
</source>
        <translation>
Script erfolgreich geladen.
Zum starten Ausführen drücken.
</translation>
    </message>
</context>
<context>
    <name>347</name>
    <message>
        <source>
Processing script failed!
</source>
        <translation>
Script konnte nicht geladen werden!
</translation>
    </message>
</context>
<context>
    <name>348</name>
    <message>
        <source>Copy<byte value="x9"/>Ctrl-C</source>
        <translation>Kopieren\tStrg-C</translation>
    </message>
</context>
<context>
    <name>349</name>
    <message>
        <source>Paste<byte value="x9"/>Ctrl-V</source>
        <translation>Einfügen\tStrg-V</translation>
    </message>
</context>
<context>
    <name>350</name>
    <message>
        <source>Select All<byte value="x9"/>Ctrl-A</source>
        <translation>Alles auswählen\tStrg-A</translation>
    </message>
</context>
<context>
    <name>351</name>
    <message>
        <source>Clear All</source>
        <translation>Alles löschen</translation>
    </message>
</context>
<context>
    <name>352</name>
    <message>
        <source>Run</source>
        <translation>Ausführen</translation>
    </message>
</context>
<context>
    <name>353</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>354</name>
    <message>
        <source>Update View</source>
        <translation>Aktualisieren</translation>
    </message>
</context>
<context>
    <name>355</name>
    <message>
        <source>New Code File</source>
        <translation>Neue Code-Datei</translation>
    </message>
</context>
<context>
    <name>356</name>
    <message>
        <source>New Directory</source>
        <translation>Neues Verzeichnis</translation>
    </message>
</context>
<context>
    <name>357</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>358</name>
    <message>
        <source>Save All</source>
        <translation>Alles speichern</translation>
    </message>
</context>
<context>
    <name>359</name>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
</context>
<context>
    <name>360</name>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>361</name>
    <message>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
</context>
<context>
    <name>362</name>
    <message>
        <source>Create new script file</source>
        <translation>Neue Quellcode-Datei erstellen</translation>
    </message>
</context>
<context>
    <name>363</name>
    <message>
        <source>Save changes of current file</source>
        <translation>Änderungen der aktuellen Datei speichern</translation>
    </message>
</context>
<context>
    <name>364</name>
    <message>
        <source>Save changes of all modified files</source>
        <translation>Änderungen aller Dateien speichern</translation>
    </message>
</context>
<context>
    <name>365</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
</context>
<context>
    <name>366</name>
    <message>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
</context>
<context>
    <name>367</name>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
</context>
<context>
    <name>368</name>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
</context>
<context>
    <name>369</name>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
</context>
<context>
    <name>370</name>
    <message>
        <source>Import script file</source>
        <translation>Quellcode-Datei importieren</translation>
    </message>
</context>
<context>
    <name>371</name>
    <message>
        <source>Export script file</source>
        <translation>Quellcode-Datei exportieren</translation>
    </message>
</context>
<context>
    <name>372</name>
    <message>
        <source>Run current script</source>
        <translation>Script ausführen</translation>
    </message>
</context>
<context>
    <name>373</name>
    <message>
        <source>Switch to minimized view</source>
        <translation>Zur alternativen Ansicht umschalten</translation>
    </message>
</context>
<context>
    <name>374</name>
    <message>
        <source>Function Catalog</source>
        <translation>Funktionsliste</translation>
    </message>
</context>
<context>
    <name>375</name>
    <message>
        <source>Do you want to save your changes?</source>
        <translation>Sollen die Änderungen gespeichert werden?</translation>
    </message>
</context>
<context>
    <name>376</name>
    <message>
        <source>Rename File</source>
        <translation>Datei umbenennen</translation>
    </message>
</context>
<context>
    <name>377</name>
    <message>
        <source>Insert new file name:</source>
        <translation>Neuen Dateinamen eingeben:</translation>
    </message>
</context>
<context>
    <name>378</name>
    <message>
        <source>Invalid name for renaming!</source>
        <translation>Der neue Dateinamen ist ungültig!</translation>
    </message>
</context>
<context>
    <name>379</name>
    <message>
        <source>Renaming of the following file failed:

</source>
        <translation>Umbenennen der folgende Datei fehlgeschlagen:

</translation>
    </message>
</context>
<context>
    <name>380</name>
    <message>
        <source>Really delete the following file?

</source>
        <translation>Soll die folgende Datei wirklich gelöscht werden?

</translation>
    </message>
</context>
<context>
    <name>381</name>
    <message>
        <source>Removing of the following file failed:

</source>
        <translation>Löschen der folgenden Datei fehlgeschlagen:

</translation>
    </message>
</context>
<context>
    <name>382</name>
    <message>
        <source>Save current File?</source>
        <translation>Soll die Datei gespeichert werden?</translation>
    </message>
</context>
<context>
    <name>383</name>
    <message>
        <source>Choose filename to create</source>
        <translation>Neuen Dateinamen eingeben</translation>
    </message>
</context>
<context>
    <name>384</name>
    <message>
        <source>Can&apos;t create file outside script directory</source>
        <translation>Es kann keine Datei außerhalb des Script-Verzeichnisses erzeugt werden</translation>
    </message>
</context>
<context>
    <name>385</name>
    <message>
        <source>Really overwrite this file?

 </source>
        <translation>Soll die folgende Datei wirklich überschrieben werden?

</translation>
    </message>
</context>
<context>
    <name>386</name>
    <message>
        <source>Unable to create file:

</source>
        <translation>Kann die folgende nicht anlegen:

</translation>
    </message>
</context>
<context>
    <name>387</name>
    <message>
        <source>Create directory</source>
        <translation>Verzeichnis anlegen</translation>
    </message>
</context>
<context>
    <name>388</name>
    <message>
        <source>Insert direcotry name:</source>
        <translation>Verzeichnisnamen eingeben:</translation>
    </message>
</context>
<context>
    <name>389</name>
    <message>
        <source>Invalid directory name</source>
        <translation>Ungültiger Verzeichnisnamen!</translation>
    </message>
</context>
<context>
    <name>390</name>
    <message>
        <source>Creating directory failed</source>
        <translation>Anlegen des Verzeichnisses fehlgeschlagen!</translation>
    </message>
</context>
<context>
    <name>391</name>
    <message>
        <source>Choose filename to save</source>
        <translation>Dateinamen zum Speichern angeben</translation>
    </message>
</context>
<context>
    <name>392</name>
    <message>
        <source>Can&apos;t save file outside script directory</source>
        <translation>Es kann keine Datei außerhalb des Script-Verzeichnisses gespeichert werden</translation>
    </message>
</context>
<context>
    <name>393</name>
    <message>
        <source>Unable to save file:</source>
        <translation>Kann folgende Datei nicht speichern:

</translation>
    </message>
</context>
<context>
    <name>394</name>
    <message>
        <source>Some code files have been modified.

Do you want to save your changes?</source>
        <translation>Es wurden Dateien verändert.

Sollen die Änderungen gespeichert werden?</translation>
    </message>
</context>
<context>
    <name>395</name>
    <message>
        <source>Error saving file </source>
        <translation>Fehler beim Speichern von </translation>
    </message>
</context>
<context>
    <name>396</name>
    <message>
        <source>Scripting Preferences</source>
        <translation>Script Einstellungen</translation>
    </message>
</context>
<context>
    <name>397</name>
    <message>
        <source>Path to scripting root directory</source>
        <translation>Pfad zum Script-Hauptverzeichnis</translation>
    </message>
</context>
<context>
    <name>398</name>
    <message>
        <source>Name of code subdirectory</source>
        <translation>Name des Quellcode-Unterverzeichnisses</translation>
    </message>
</context>
<context>
    <name>399</name>
    <message>
        <source>Name of data subdirectory</source>
        <translation>Name des Daten-Unterverzeichnisses</translation>
    </message>
</context>
<context>
    <name>400</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>401</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>402</name>
    <message>
        <source>Search</source>
        <translation>Durchsuchen</translation>
    </message>
</context>
<context>
    <name>403</name>
    <message>
        <source>Clear array memory after script running</source>
        <translation>Array-Speicher vor Script-Start löschen</translation>
    </message>
</context>
<context>
    <name>404</name>
    <message>
        <source>Please insert complete Path</source>
        <translation>Bitte geben Sie den Pfad vollständig an.</translation>
    </message>
</context>
<context>
    <name>405</name>
    <message>
        <source>Can&apos;t create scripting root directory</source>
        <translation>Script-Hauptverzeichnis konnte nicht erzeugt werden.</translation>
    </message>
</context>
<context>
    <name>406</name>
    <message>
        <source>Invalid path to scripting root directory</source>
        <translation>Der Pfad zum Script-Hauptverzeichnis ist ungültig</translation>
    </message>
</context>
<context>
    <name>407</name>
    <message>
        <source>Can&apos;t create code subdirectory</source>
        <translation>Quellcode-Unterverzeichnis konnte nicht erzeugt werden</translation>
    </message>
</context>
<context>
    <name>408</name>
    <message>
        <source>Invalid scripting subdirectory name</source>
        <translation>Der Name des Quellcode-Unterverzeichnisses ist ungültig.</translation>
    </message>
</context>
<context>
    <name>409</name>
    <message>
        <source>Can&apos;t create data subdirectory</source>
        <translation>Daten-Unterverzeichnis konnte nicht erzeugt werden</translation>
    </message>
</context>
<context>
    <name>410</name>
    <message>
        <source>Invalid data subdirectory name</source>
        <translation>Der Name des Daten-Unterverzeichnisses ist ungültig.</translation>
    </message>
</context>
<context>
    <name>411</name>
    <message>
        <source>Choose a directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
</context>
<context>
    <name>412</name>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>413</name>
    <message>
        <source>Rows</source>
        <translation>Zeilen</translation>
    </message>
</context>
<context>
    <name>414</name>
    <message>
        <source>Columns</source>
        <translation>Spalten</translation>
    </message>
</context>
<context>
    <name>415</name>
    <message>
        <source>Calculator</source>
        <translation>Rechner</translation>
    </message>
</context>
<context>
    <name>416</name>
    <message>
        <source>Solve Equations</source>
        <translation>Lineares Gleichungssystem</translation>
    </message>
</context>
<context>
    <name>417</name>
    <message>
        <source>Generate Matrix</source>
        <translation>Erstellen</translation>
    </message>
</context>
<context>
    <name>418</name>
    <message>
        <source>Analyse Matrix</source>
        <translation>Analysieren</translation>
    </message>
</context>
<context>
    <name>419</name>
    <message>
        <source>Inverse Matrix</source>
        <translation>Inverse Matrix</translation>
    </message>
</context>
<context>
    <name>420</name>
    <message>
        <source>Calculate</source>
        <translation>Berechnen</translation>
    </message>
</context>
<context>
    <name>421</name>
    <message>
        <source>Set</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>422</name>
    <message>
        <source>no vector</source>
        <translation>Kein Vektor</translation>
    </message>
</context>
<context>
    <name>423</name>
    <message>
        <source>Identity Matrix</source>
        <translation>Einheitsmatrix</translation>
    </message>
</context>
<context>
    <name>424</name>
    <message>
        <source>Zero Matrix</source>
        <translation>Nullmatrix</translation>
    </message>
</context>
<context>
    <name>425</name>
    <message>
        <source>Zero Vector</source>
        <translation>Nullvektor</translation>
    </message>
</context>
<context>
    <name>426</name>
    <message>
        <source>X-Rotation Matrix</source>
        <translation>X-Drehmatrix</translation>
    </message>
</context>
<context>
    <name>427</name>
    <message>
        <source>Y-Rotation Matrix</source>
        <translation>Y-Drehmatrix</translation>
    </message>
</context>
<context>
    <name>428</name>
    <message>
        <source>Z-Rotation Matrix</source>
        <translation>Z-Drehmatrix</translation>
    </message>
</context>
<context>
    <name>429</name>
    <message>
        <source>Scaling Matrix</source>
        <translation>Skalierungsmatrix</translation>
    </message>
</context>
<context>
    <name>430</name>
    <message>
        <source>Vector</source>
        <translation>Vektor</translation>
    </message>
</context>
<context>
    <name>431</name>
    <message>
        <source>Unknowns:</source>
        <translation>Unbekannte:</translation>
    </message>
</context>
<context>
    <name>432</name>
    <message>
        <source>Matrix</source>
        <translation>Matrix</translation>
    </message>
</context>
<context>
    <name>433</name>
    <message>
        <source>Choose a Matrix
or a Matrix and a Vector
to insert data
</source>
        <translation>Matrix oder 
Matrix und Vektor auswählen</translation>
    </message>
</context>
<context>
    <name>434</name>
    <message>
        <source>Variable</source>
        <translation>Variable</translation>
    </message>
</context>
<context>
    <name>435</name>
    <message>
        <source>Generate</source>
        <translation>Erzeugen</translation>
    </message>
</context>
<context>
    <name>436</name>
    <message>
        <source>Gauss</source>
        <translation>Gauß</translation>
    </message>
</context>
<context>
    <name>437</name>
    <message>
        <source>Type: Matrix</source>
        <translation>Typ: Matrix</translation>
    </message>
</context>
<context>
    <name>438</name>
    <message>
        <source>Dimensions:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>439</name>
    <message>
        <source>Determinant:</source>
        <translation>Determinante:</translation>
    </message>
</context>
<context>
    <name>440</name>
    <message>
        <source>not possible</source>
        <translation>Nicht möglich</translation>
    </message>
</context>
<context>
    <name>441</name>
    <message>
        <source>Rank:</source>
        <translation>Rang:</translation>
    </message>
</context>
<context>
    <name>442</name>
    <message>
        <source>Type: Vector</source>
        <translation>Typ: Vektor</translation>
    </message>
</context>
<context>
    <name>443</name>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>444</name>
    <message>
        <source>Absolute:</source>
        <translation>Betrag:</translation>
    </message>
</context>
<context>
    <name>445</name>
    <message>
        <source>Type: Scalar</source>
        <translation>Type: Skalar</translation>
    </message>
</context>
<context>
    <name>446</name>
    <message>
        <source>Can&apos;t choose the same variable twice!
Choose a matrix,
or a matrix and a vector
to insert data</source>
        <translation>Variable doppelt ausgewählt!
Matrix oder 
Matrix und Vektor auswählen</translation>
    </message>
</context>
<context>
    <name>447</name>
    <message>
        <source>Insert data 
and press calculate button</source>
        <translation>Werte eingeben 
und Berechnen drücken</translation>
    </message>
</context>
<context>
    <name>448</name>
    <message>
        <source>Press set button to adjust size</source>
        <translation>Ok-Knopf zum Übernehmen drücken</translation>
    </message>
</context>
<context>
    <name>449</name>
    <message>
        <source>Insert data 
and press calculate button</source>
        <translation>Werte eingeben 
und Berechnen drücken</translation>
    </message>
</context>
<context>
    <name>450</name>
    <message>
        <source>Press set button to adjust size</source>
        <translation>Ok-Knopf zum Übernehmen drücken</translation>
    </message>
</context>
<context>
    <name>451</name>
    <message>
        <source>x angle</source>
        <translation>x-Winkel</translation>
    </message>
</context>
<context>
    <name>452</name>
    <message>
        <source>y angle</source>
        <translation>y-Winkel</translation>
    </message>
</context>
<context>
    <name>453</name>
    <message>
        <source>z angle</source>
        <translation>z-Winkel</translation>
    </message>
</context>
<context>
    <name>454</name>
    <message>
        <source>x scale</source>
        <translation>x-Skalierung</translation>
    </message>
</context>
<context>
    <name>455</name>
    <message>
        <source>y scale</source>
        <translation>y-Skalierung</translation>
    </message>
</context>
<context>
    <name>456</name>
    <message>
        <source>z scale</source>
        <translation>z-Skalierung</translation>
    </message>
</context>
<context>
    <name>457</name>
    <message>
        <source>More than one result found
Showing matrix</source>
        <translation>Mehr als ein Ergebnis gefunden
Matrix wird angezeigt</translation>
    </message>
</context>
<context>
    <name>458</name>
    <message>
        <source>No results found
Showing matrix</source>
        <translation>Kein Ergebnis gefunden
Matrix wird angezeigt</translation>
    </message>
</context>
<context>
    <name>459</name>
    <message>
        <source>Showing result Vector</source>
        <translation>Ergebnisvektor</translation>
    </message>
</context>
<context>
    <name>460</name>
    <message>
        <source>Number of rows of matrix must 
be equal to number of columns.</source>
        <translation>Zeilen- und Spaltenzahl der Matrix 
müssen gleich sein</translation>
    </message>
</context>
<context>
    <name>461</name>
    <message>
        <source>Can&apos;t calculate inverse matrix.
Determinant is equal 0.</source>
        <translation>Inverse Matrix kann nicht berechnent werden
Determinante ist gleich 0.</translation>
    </message>
</context>
<context>
    <name>462</name>
    <message>
        <source>Function Type</source>
        <translation>Funktionstyp</translation>
    </message>
</context>
<context>
    <name>463</name>
    <message>
        <source>Input List Number</source>
        <translation>Listennummer</translation>
    </message>
</context>
<context>
    <name>464</name>
    <message>
        <source>Result Function</source>
        <translation>Ergebnisfunktion</translation>
    </message>
</context>
<context>
    <name>465</name>
    <message>
        <source>Copy to</source>
        <translation>Kopieren nach</translation>
    </message>
</context>
<context>
    <name>466</name>
    <message>
        <source>Copy</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>467</name>
    <message>
        <source>Approximate</source>
        <translation>Approximation</translation>
    </message>
</context>
<context>
    <name>468</name>
    <message>
        <source>Interpolate</source>
        <translation>Interpolation</translation>
    </message>
</context>
<context>
    <name>469</name>
    <message>
        <source>Show Line-Graph</source>
        <translation>Liniendiagramm anzeigen</translation>
    </message>
</context>
<context>
    <name>470</name>
    <message>
        <source>Normal Distribution</source>
        <translation>Normalverteilung</translation>
    </message>
</context>
<context>
    <name>471</name>
    <message>
        <source>Distribution Graph</source>
        <translation>Verteilungskurve</translation>
    </message>
</context>
<context>
    <name>472</name>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
</context>
<context>
    <name>473</name>
    <message>
        <source>Calculate</source>
        <translation>Berechnen</translation>
    </message>
</context>
<context>
    <name>474</name>
    <message>
        <source>Print</source>
        <translation>Zeichnen</translation>
    </message>
</context>
<context>
    <name>475</name>
    <message>
        <source>Really overwrite function f</source>
        <translation>Funktion f</translation>
    </message>
</context>
<context>
    <name>476</name>
    <message>
        <source> ?</source>
        <translation> wirklich überschreiben ?</translation>
    </message>
</context>
<context>
    <name>477</name>
    <message>
        <source>Unable to write lists file: </source>
        <translation>Datei konnte nicht geschrieben werden: </translation>
    </message>
</context>
<context>
    <name>478</name>
    <message>
        <source>Unable to read lists file: </source>
        <translation>Datei konnte nicht gelesen werden: </translation>
    </message>
</context>
<context>
    <name>479</name>
    <message>
        <source>For this approximation, at least one point is needed</source>
        <translation>Für diese Operation wird mindestens ein Punkt benötigt</translation>
    </message>
</context>
<context>
    <name>480</name>
    <message>
        <source>For this approximation, at least two points were needed</source>
        <translation>Für diese Operation werden mindestens zwei Punkte benötigt</translation>
    </message>
</context>
<context>
    <name>481</name>
    <message>
        <source>For this approximation, at least three points were needed</source>
        <translation>Für diese Operation werden mindestens drei Punkte benötigt</translation>
    </message>
</context>
<context>
    <name>CalcWidget</name>
    <message>
        <source>Constants and conversation</source>
        <translation>Konstanten und Umrechnungsfaktoren</translation>
    </message>
</context>
<context>
    <name>Catalog</name>
    <message>
        <source>Mathematics Constants</source>
        <translation>Mathematische Konstanten
</translation>
    </message>
    <message>
        <source>Physics Constants</source>
        <translation>Physikalische Konstanten</translation>
    </message>
    <message>
        <source>Conversation Constants</source>
        <translation>Umrechnungsfaktoren</translation>
    </message>
    <message>
        <source>Userdefined Constants</source>
        <translation>Benutzerdefinierte Konstanten</translation>
    </message>
    <message>
        <source>Math Standard</source>
        <translation>Mathematik standard</translation>
    </message>
    <message>
        <source>Math Trigonometric</source>
        <translation>Mathematik trigonometrisch</translation>
    </message>
    <message>
        <source>Math Extended</source>
        <translation>Mathematik erweitert</translation>
    </message>
    <message>
        <source>Math Logic</source>
        <translation>Mathematik Logik</translation>
    </message>
    <message>
        <source>Matrix/Vector</source>
        <translation>Matrix/Vektor</translation>
    </message>
    <message>
        <source>Script Standard</source>
        <translation>Script Standard</translation>
    </message>
    <message>
        <source>Script Text</source>
        <translation>Script Text</translation>
    </message>
    <message>
        <source>Script Graphics</source>
        <translation>Script Grafik</translation>
    </message>
    <message>
        <source>Script GL</source>
        <translation>Script GL</translation>
    </message>
    <message>
        <source>Script File</source>
        <translation>Script Dateien</translation>
    </message>
</context>
<context>
    <name>ConstantDialog</name>
    <message>
        <source>Change Constants</source>
        <translation>Konstanten ändern</translation>
    </message>
    <message>
        <source>Choose Constant</source>
        <translation>Konstanten</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <source>Identifier</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Übernehmen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
</context>
<context>
    <name>FunctionTable</name>
    <message>
        <source>dynamic</source>
        <translation>dynamisch</translation>
    </message>
    <message>
        <source>logic expressions</source>
        <translation>Logikfunktionen</translation>
    </message>
    <message>
        <source>comment</source>
        <translation>Kommentar</translation>
    </message>
</context>
<context>
    <name>GraphOutput</name>
    <message>
        <source>Processing ...</source>
        <translation>Berechnung ...</translation>
    </message>
</context>
<context>
    <name>GraphSolveWidget</name>
    <message>
        <source>This operation can&apos;t be executed for graphs that use logic expressions!</source>
        <translation>Diese Operation ist bei Graphen, die Logikfunktionen enthalten, nicht erlaubt!</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <source>Function</source>
        <translation type="obsolete">Funktion</translation>
    </message>
    <message>
        <source>Import to</source>
        <translation type="obsolete">Ziel</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Export</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="obsolete">Kommentar</translation>
    </message>
    <message>
        <source>Error

No functions marked for export!</source>
        <translation type="obsolete">Fehler

Keine Funktionen zum Export ausgewählt!</translation>
    </message>
    <message>
        <source>Unable to write file: </source>
        <translation type="obsolete">Die Datei konnte nicht geschrieben werden: </translation>
    </message>
    <message>
        <source>Really overwrite F%1?</source>
        <translation type="obsolete">Soll F%1 wirklich überschrieben werden?</translation>
    </message>
    <message>
        <source>Unable to open file: </source>
        <translation type="obsolete">Die Datei konnte nicht geöffnet werden: </translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Keine
</translation>
    </message>
    <message>
        <source>Import Graph File</source>
        <translation>Graphen importieren</translation>
    </message>
    <message>
        <source>Export Graph File</source>
        <translation>Graphen exportieren</translation>
    </message>
</context>
<context>
    <name>MainObject</name>
    <message>
        <source>Import Graphs</source>
        <translation>Graphen importieren</translation>
    </message>
    <message>
        <source>Export Graphs</source>
        <translation>Graphen exportieren</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Französisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>pi </source>
        <translation>Pi </translation>
    </message>
    <message>
        <source>euler number e</source>
        <translation>Eulerzahl e</translation>
    </message>
    <message>
        <source>euler constant C</source>
        <translation>Eulersche Konstante C</translation>
    </message>
    <message>
        <source>vacuum light speed c0 [m/s]</source>
        <translation>Vakuumlichtgeschwindigkeit c0 [m/s]</translation>
    </message>
    <message>
        <source>standard acceleration of gravity g [m/s^2]</source>
        <translation>Fallbeschleunigung g [m/s^2]</translation>
    </message>
    <message>
        <source>Newtonian constant of gravitation G [m^3/(kg s^2)]</source>
        <translation>Newtonsche Gravitationskonstante G [m^3/(kg s^2)]</translation>
    </message>
    <message>
        <source>electric field constant e0 [F/m]</source>
        <translation>Permittivität des Vakuums e0 [F/m]</translation>
    </message>
    <message>
        <source>magnetic field constant my0 [N/A^2]</source>
        <translation>Permeabilität des Vakuums my0 [N/A^2]</translation>
    </message>
    <message>
        <source>Planck constant h [Js]</source>
        <translation>Plancksches Wirkungsquantum h [Js]</translation>
    </message>
    <message>
        <source>Planck constant h [eVs]</source>
        <translation>Plancksches Wirkungsquantum h [eVs]</translation>
    </message>
    <message>
        <source>characteristic impedance of vacuum Z0 [V/A]</source>
        <translation>Wellenwiderstand des Vakuums Z0 [V/A]</translation>
    </message>
    <message>
        <source>Faraday constant F [C/mol]</source>
        <translation>Faraday Konstante F [C/mol]</translation>
    </message>
    <message>
        <source>atomic unit of charge e [C]</source>
        <translation>Elementrladung e [C]</translation>
    </message>
    <message>
        <source>fine-structure constant alpha</source>
        <translation>Feinstrukturkonstante alpha</translation>
    </message>
    <message>
        <source>atomic mass constant mu [kg]</source>
        <translation>Atomare Masseneinheit mu [kg]</translation>
    </message>
    <message>
        <source>electron mass me [kg]</source>
        <translation>Masse Elektron me [kg]</translation>
    </message>
    <message>
        <source>neutron mass mn [kg]</source>
        <translation>Masse Neutron mn [kg]</translation>
    </message>
    <message>
        <source>proton mass mp [kg]</source>
        <translation>Masse Proton mp [kg]</translation>
    </message>
    <message>
        <source>Avogadro constant [1/mol]</source>
        <translation>Avogadrokonstante [1/mol]</translation>
    </message>
    <message>
        <source>Boltzmann constant k [J/K]</source>
        <translation>Boltzmann Konstante k [J/K]</translation>
    </message>
    <message>
        <source>molar gas constant R0 [J/(mol K)]</source>
        <translation>Allgemeine Gaskonstante R0 [J/(mol K)]</translation>
    </message>
    <message>
        <source>Stefan-Boltzmann constant sigma [W/(M^2 K^4)]</source>
        <translation>Sefan-Boltzmann Konstante sigma [W/(M^2 K^4)]</translation>
    </message>
    <message>
        <source>Wien wavelength displacement law constant b [m K]</source>
        <translation>Wiensche Verschiebungskonstante b [m K]</translation>
    </message>
    <message>
        <source>km -&gt; mile</source>
        <translation>km -&gt; Meile</translation>
    </message>
    <message>
        <source>mile -&gt; km</source>
        <translation>Meile -&gt; km</translation>
    </message>
    <message>
        <source>cm -&gt; inch</source>
        <translation>cm -&gt; inch</translation>
    </message>
    <message>
        <source>inch -&gt; cm</source>
        <translation>inch -&gt; cm</translation>
    </message>
    <message>
        <source>g -&gt; oz</source>
        <translation>g -&gt; oz</translation>
    </message>
    <message>
        <source>oz -&gt; g</source>
        <translation>oz -&gt; g</translation>
    </message>
    <message>
        <source>J -&gt; calorie</source>
        <translation>J -&gt; Kalorie</translation>
    </message>
    <message>
        <source>calorie -&gt; J</source>
        <translation>Kalorie -&gt; J</translation>
    </message>
    <message>
        <source>Can&apos;t read constants file %1.

</source>
        <translation>Konstantenverzeichnis %1 konnte nicht geladen werden.

</translation>
    </message>
    <message>
        <source>Constants file %1 could not be written.

</source>
        <translation>Konstantenverzeichnis %1 konnte nicht gespeichert werden.

</translation>
    </message>
    <message>
        <source>Extcalc must be restarted to apply this changes!

Restart now?</source>
        <translation>Um die Änderungen zu übernehmen, muss Extcalc neu gestartet werden.

Jetzt neu starten?</translation>
    </message>
    <message>
        <source>Choose Current Set</source>
        <translation>Aktuelle Gruppe auswählen</translation>
    </message>
    <message>
        <source>Manage Sets</source>
        <translation>Gruppen verwalten</translation>
    </message>
    <message>
        <source>Save Current Set As</source>
        <translation>Gruppe speichern unter</translation>
    </message>
    <message>
        <source>Create New Set</source>
        <translation>Neue Gruppe</translation>
    </message>
    <message>
        <source>Create New Graph Set</source>
        <translation>Neue Gruppe</translation>
    </message>
    <message>
        <source>Insert name of new graph set:</source>
        <translation>Name der Gruppe:</translation>
    </message>
    <message>
        <source>Invalid graph set name %1</source>
        <translation>Ungültiger Gruppenname %1</translation>
    </message>
    <message>
        <source>%1 already exists!

Overwrite it?</source>
        <translation>%1 existiert bereits!

Überscheiben?</translation>
    </message>
    <message>
        <source>Save Curren Graph Set As</source>
        <translation type="obsolete">Gruppe speichern unter</translation>
    </message>
    <message>
        <source>Insert new name of graph set:</source>
        <translation>Name der Gruppe:</translation>
    </message>
    <message>
        <source>Unable to read file %1

</source>
        <translation>%1 kann nicht gelesen werden

</translation>
    </message>
    <message>
        <source>Unable to read graphs file %1

</source>
        <translation>%1 kann nicht gelesen werden</translation>
    </message>
    <message>
        <source>Unable to write graphs file %1

</source>
        <translation>%1 kann nicht geschrieben werden</translation>
    </message>
    <message>
        <source>Unable to create graphs directory %1

</source>
        <translation>%1 konnte nicht erstellt werden</translation>
    </message>
    <message>
        <source>Save Current Graph Set As</source>
        <translation>Gruppe speichern unter</translation>
    </message>
</context>
</TS>
